import { useState, useEffect } from 'react';
import { Button, Card, Descriptions, Input, List } from 'antd';
import { getHatcDeviceList } from '@/services/device';
import selectedImg from '@/assets/selectedImg.png';

const { Search } = Input;

// 列表是海康设备
// props 传过来的是映射ID

export default (props) => {
  const { value, onChange } = props;

  const [loading, setLoading] = useState(false);
  const [hatcDeviceList, setHatcDeviceList] = useState([]); // 所有数据
  const [list, setList] = useState([]); // 页面展示数据
  const [checked, setChecked] = useState();

  // 搜索
  const onSearch = (val) => {
    if (val == '' || val === undefined || val === null) {
      setList(hatcDeviceList);
    } else {
      setList(hatcDeviceList.filter((x) => x.terminalId.toLowerCase().includes(val.toLowerCase())));
    }
  };

  //选中设备
  const handleSelect = (item) => {
    setChecked(item);
  };

  // 提交
  const handleSubmit = () => {
    onChange(checked.terminalId, checked);
  };

  // 过滤列表
  useEffect(() => {
    setLoading(true);
    getHatcDeviceList({ pageSize: 500 })
      .then((res) => {
        setHatcDeviceList(res.records);
        setList(res.records);
        setLoading(false);
      })
      .catch(() => {
        setLoading(false);
      });
  }, []);

  useEffect(() => {
    if (!hatcDeviceList || !hatcDeviceList.length) return;
    if (!value) return;

    if (!checked || value !== checked.terminalId) {
      const target = hatcDeviceList.filter((x) => x.terminalId === value)[0];
      setChecked(target);
    }
  }, [value, checked, hatcDeviceList]);

  return (
    <div style={{ display: 'flex', height: '100%', flexDirection: 'column' }}>
      <Search
        placeholder="请输入终端ID"
        allowClear
        enterButton="搜索"
        size="middle"
        onSearch={onSearch}
        style={{ padding: '24px' }}
      />
      <List
        split={false}
        style={{ padding: '12px 0', flex: 1, overflowY: 'auto', background: 'rgb(240,242,245)' }}
      >
        {list.map((item) => (
          <List.Item key={item.deviceId} onClick={() => handleSelect(item)}>
            <Card className="listCard" hoverable>
              <Descriptions
                labelStyle={{ width: '72px', display: 'inline-block', textAlign: 'end' }}
              >
                <Descriptions.Item span={3} label="型号名称">
                  {item.modelName}
                </Descriptions.Item>
                <Descriptions.Item span={3} label="协议">
                  {item.protocol}
                </Descriptions.Item>
                <Descriptions.Item span={3} label="终端ID">
                  {item.terminalId}
                </Descriptions.Item>
                <Descriptions.Item span={3} label="通道列表">
                  {item.deviceChannelList}
                </Descriptions.Item>
              </Descriptions>
              {checked && checked.deviceId === item.deviceId && <img src={selectedImg} />}
            </Card>
          </List.Item>
        ))}
      </List>
      <div style={{ padding: '24px' }}>
        <Button
          type="primary"
          style={{ float: 'right' }}
          loading={loading}
          onClick={handleSubmit}
          disabled={!checked}
        >
          确定
        </Button>
      </div>
    </div>
  );
};
