import React, { useState, useRef, useMemo } from 'react';
import { Link } from 'umi';
import { Button, Card, Table, message, Descriptions, Col, Row } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getDeviceJobByOrg, exportDeviceJobByOrg } from '@/services/job';
import Search from './components/search';

export default (props) => {
  const { location } = props;
  const { deviceType, deviceNo } = location.query || {};

  const columns = [
    {
      title: '合作社',
      dataIndex: 'orgName',
      key: 'orgName',
    },
    {
      title: '人员',
      dataIndex: 'userName',
      key: 'userName',
      render: (t, record) => (
        <Link to={`/iot/OperationStatistics/detail?user=${record.userId}`}>{t || '-'}</Link>
      ),
    },
    {
      title: '手机',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '农机',
      dataIndex: 'machineryName',
      key: 'machineryName',
    },
    {
      title: '设备类型',
      dataIndex: 'deviceKind',
      key: 'deviceKind',
      render: (t) => (t === 'shensong' ? '深松' : t === 'feifang' ? '飞防' : '-'),
    },
    {
      title: '设备编号',
      dataIndex: 'deviceNo',
      key: 'deviceNo',
    },
    {
      title: '作业面积(亩)',
      dataIndex: 'jobArea',
      key: 'jobArea',
    },
    {
      title: '位置',
      dataIndex: 'address',
      search: false,
      // key: 'orgName',
    },
    {
      title: '作业时间',
      dataIndex: 'jobTime',
      key: 'jobTime',
    },
  ];

  const [loading, setLoading] = useState(false);
  const [list, setList] = useState([]);
  const [total, setTotal] = useState(0);
  const [page, setPage] = useState({ current: 1, pageSize: 10, total: 0 });
  const searchValue = useRef({});

  const pagination = useMemo(
    () => ({
      ...page,
      showTotal: (total, range) => `总计 ${total} 条`,
      onChange: (page, pageSize) => {
        setPage({
          current: page,
          pageSize,
          total: 0,
        });

        queryData({
          ...searchValue.current,
          pageNum: page,
          pageSize,
        });
      },
    }),
    [page],
  );

  const queryData = (params) => {
    setLoading(true);
    getDeviceJobByOrg(params)
      .then((res) => {
        setLoading(false);
        const { list: dtList, totalArea } = res;
        setList(dtList.records || []);
        setTotal(totalArea || 0);
        setPage({
          current: dtList.current,
          pageSize: dtList.size,
          total: dtList.total,
        });
      })
      .catch((err) => {
        console.error(err);
        setLoading(false);
      });
  };

  const exportData = () => {
    setLoading(true);
    exportDeviceJobByOrg(searchValue.current)
      .then(() => setLoading(false))
      .catch((err) => {
        console.error(err);
        setLoading(false);
      });
  };

  const onSearch = (params = {}) => {
    searchValue.current = params;
    queryData({
      ...params,
      pageNum: 1,
      pageSize: page.pageSize,
    });
  };

  return (
    <PageHeaderWrapper>
      <div style={{ marginBottom: '16px' }}>
        <Search initial={{ deviceKind: deviceType, deviceNo }} onFinish={onSearch} />
      </div>
      <Card loading={loading}>
        <Row>
          <Col span={12}>
            <div style={{ textAlign: 'left', marginBottom: '16px', fontSize: '16px' }}>
              <span>总作业面积 </span>
              <strong>{total}</strong>
              <span> 亩</span>
            </div>
          </Col>
          <Col span={12}>
            <div style={{ textAlign: 'right', marginBottom: '16px' }}>
              <Button type="primary" onClick={exportData}>
                导出
              </Button>
            </div>
          </Col>
        </Row>
        <Table rowKey="jobNo" columns={columns} dataSource={list} pagination={pagination} />
      </Card>
    </PageHeaderWrapper>
  );
};
