import React from 'react';
import { Upload, Spin, Collapse, Space, Typography, Button } from 'antd';
import { InboxOutlined } from '@ant-design/icons';
import { read, utils } from 'xlsx';
import { addRawDevice } from '@/services/device';

const { Dragger } = Upload;
const { Panel } = Collapse;
const { Text } = Typography;
const deviceKind = 'feifang';

export default React.forwardRef((props, ref) => {
  const { onCancel, onFinish } = props;

  const [loading, setLoading] = React.useState(false);
  const [finished, setFinished] = React.useState(false);
  const [deviceNoList, setDeviceNoList] = React.useState([]);
  const [okList, setOkList] = React.useState([]);
  const [failList, setFailList] = React.useState([]);

  const okListRef = React.useRef();
  okListRef.current = okList;
  const failListRef = React.useRef();
  failListRef.current = failList;

  const loadingTip = React.useMemo(() => {
    return `正在处理 ${okList.length + failList.length} / ${deviceNoList.length}`;
  }, [deviceNoList, okList, failList]);

  const beforeUpload = (file) => {
    const reader = new FileReader();
    reader.onload = (e) => {
      const wb = read(e.target.result);
      // data 格式为 [{ "设备号": "xxx" }], 其中 xxx 为设备号
      const data = utils.sheet_to_json(wb.Sheets[wb.SheetNames[0]]) || [];
      const list = data.map((x) => x['设备号']);
      setDeviceNoList(list || []);
      setOkList([]);
      setFailList([]);
      setFinished(false);
    };
    reader.readAsArrayBuffer(file);

    // 不上传
    return false;
  };

  React.useEffect(() => {
    if (!deviceNoList || !deviceNoList.length) return;

    setLoading(true);
    setOkList([]);
    setFailList([]);

    let i = 0;
    for (let deviceNo of deviceNoList) {
      addRawDevice({ deviceKind, deviceNo }, { showType: 0 })
        .then(() => {
          i += 1;
          okListRef.current = okListRef.current.concat(deviceNo);
          setOkList(okListRef.current);
          setFinished(i >= deviceNoList.length);
        })
        .catch(() => {
          i += 1;
          failListRef.current = failListRef.current.concat(deviceNo);
          setFailList(failListRef.current);
          setFinished(i >= deviceNoList.length);
        });
    }
  }, [deviceNoList]);

  React.useImperativeHandle(
    ref,
    () => ({
      refresh: () => {
        setLoading(false);
        setFinished(false);
        setDeviceNoList([]);
        setOkList([]);
        setFailList([]);
      },
    }),
    [],
  );

  return (
    <div>
      {!finished && (
        <Spin spinning={loading} tip={loadingTip}>
          <Dragger accept=".xls,.xlsx" fileList={[]} beforeUpload={beforeUpload}>
            <p className="ant-upload-drag-icon">
              <InboxOutlined />
            </p>
            <p className="ant-upload-text">点击或拖拽 Excel 文件到此区域</p>
            <p className="ant-upload-hint">
              Excel 要求只有一列, 标题为"设备号"（不带引号）, 数据从第二行开始
            </p>
          </Dragger>
        </Spin>
      )}
      {finished && (
        <Space direction="vertical">
          <Collapse collapsible="header" defaultActiveKey={['1']}>
            <Panel header="成功设备" key="1">
              <Typography>
                {okList.map((x) => (
                  <Text copyable key={x}>
                    {x}
                  </Text>
                ))}
              </Typography>
            </Panel>
          </Collapse>
          <Collapse collapsible="header" defaultActiveKey={['1']}>
            <Panel header="失败设备" key="1">
              <Typography>
                {failList.map((x) => (
                  <Text copyable key={x}>
                    {x}
                  </Text>
                ))}
              </Typography>
            </Panel>
          </Collapse>
        </Space>
      )}
    </div>
  );
});
