import React from 'react';
import { Modal, Form, Select, Button } from 'antd';
import { getMachineryTypeList } from '@/services/machineryType';
import { getMachineryList } from '@/services/machinery';

const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
const FormItem = Form.Item;
const Option = Select.Option;

export default (props) => {
  const { onCancel, onFinish } = props;

  const [form] = Form.useForm();
  const [machineryTypeList, setMachineryTypeList] = React.useState([]);
  const [typeId, setTypeId] = React.useState();
  const [machineryList, setMachineryList] = React.useState([]);
  const [machineryId, setMachineryId] = React.useState();

  // 查询分类列表, 构造下拉框
  React.useEffect(() => {
    getMachineryTypeList({ pageSize: 999 })
      .then((res) => {
        setMachineryTypeList(res.records);
      })
      .catch((err) => {
        console.log(err.message);
      });
  }, []);

  // 联动下拉列表
  React.useEffect(() => {
    if (typeId) {
      getMachineryList({ typeId })
        .then((e) => {
          setMachineryList(e.records || []);
        })
        .catch((err) => {
          console.log(err.message);
        });
    }
  }, [typeId]);

  return (
    <Form {...formItemLayout} onFinish={onFinish} form={form}>
      <FormItem
        label="农机分类"
        name="typeId"
        rules={[{ required: true, message: '请选择农机分类' }]}
      >
        <Select value={typeId} onChange={setTypeId} allowClear style={{ width: '320px' }}>
          {machineryTypeList.map((item) => (
            <Option value={item.typeId} key={item.typeId}>
              {item.name}
            </Option>
          ))}
        </Select>
      </FormItem>
      <FormItem
        label="选择农机"
        name="machineryId"
        rules={[{ required: true, message: '请选择农机名' }]}
      >
        <Select value={machineryId} onChange={setMachineryId} allowClear style={{ width: '320px' }}>
          {machineryList.map((item) => (
            <Option value={item.machineryId} key={item.machineryId}>
              {item.name}
            </Option>
          ))}
        </Select>
      </FormItem>
      <FormItem label=" " colon={false}>
        <Button type="default" onClick={onCancel}>
          取消
        </Button>
        <Button type="primary" htmlType="Submit" style={{ marginLeft: '2em' }}>
          确认
        </Button>
      </FormItem>
    </Form>
  );
};
