import React, { useState, useEffect, useRef } from 'react';
import { Button, Modal, Select, Form, message } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import {
  addDevice,
  deleteDevice,
  syncShenSong,
  addRawDevice,
  deleteRawDevice,
  syncLoc,
  syncMachine,
} from '@/services/device';
import List from './components/List';
import MaBind from './components/MaBind';
import FeiFangForm from './components/FeiFangForm';

export default (props) => {
  const [open, setOpen] = useState(false);
  const [syncing, setSyncing] = React.useState(false);
  const [syncing2, setSyncing2] = React.useState(false);
  const [syncing3, setSyncing3] = React.useState(false);
  const [device, setDevice] = useState();
  const listRef = useRef();
  const actRef = useRef();
  const ffRef = useRef();

  const modalTitle = actRef.current === 'add' ? '新增设备' : '绑定农机';

  // 绑定农机
  const onBind = ({ machineryId }) => {
    const hide = message.loading('请稍候...', 0);
    const data = { ...device, machineryId };
    addDevice(data)
      .then((res) => {
        hide();
        setOpen(false);
        message.success(`绑定成功`);
        listRef.current.reload();
      })
      .catch((err) => {
        hide();
        message.error(err.message || err);
      });
  };

  // 解绑
  const unBind = ({ deviceType, deviceNo }) => {
    const hide = message.loading('请稍候...', 0);
    deleteDevice({ deviceType, deviceNo })
      .then(() => {
        hide();
        message.success(`解绑成功`);
        listRef.current.reload();
      })
      .catch((err) => {
        hide();
        message.error(err.message || err);
      });
  };

  // 删除设备
  const onDelete = (row) => {
    const hide = message.loading('请稍候...', 0);
    deleteRawDevice(row.deviceId)
      .then(() => {
        hide();
        message.success('删除成功');
        listRef.current.reload();
      })
      .catch((err) => {
        hide();
        message.error(err.message || err);
      });
  };

  // 新增设备
  const onAddDevice = ({ deviceNo, deviceKind = 'feifang' }) => {
    setSyncing2(true);
    addRawDevice({ deviceKind, deviceNo })
      .then((res) => {
        message.success('添加设备成功');
        setSyncing2(false);
        setOpen(false);
        listRef.current.reload();
      })
      .catch((err) => {
        setSyncing2(false);
      });
  };

  // 同步深松
  const onSyncShenSong = () => {
    setSyncing(true);
    syncShenSong()
      .then((res) => {
        setSyncing(false);
        listRef.current.reload();
        message.success('同步完成');
      })
      .catch(() => {
        setSyncing(false);
      });
  };

  // 同步飞防
  const onSyncFeiFang = () => {
    actRef.current = 'add';
    setOpen(true);
  };

  // 同步农机
  const onSyncMachine = () => {
    setSyncing3(true);
    syncMachine()
      .then((res) => {
        setSyncing3(false);
        message.success('同步完成');
      })
      .catch(() => {
        setSyncing3(false);
      });
  };

  const onSyncLoc = ({ deviceType, deviceNo }) => {
    const hide = message.loading('请稍候...', 0);
    syncLoc({ deviceType, deviceNo })
      .then(() => {
        hide();
        message.success('同步定位成功');
      })
      .catch(() => {
        hide();
      });
  };

  const onHide = () => {
    setOpen(false);
    if (ffRef.current) {
      ffRef.current.refresh();
    }
  };

  // 设备操作
  const onOperate = (row, act) => {
    actRef.current = act;
    setDevice({ ...row });

    switch (act) {
      case 'bind':
        setOpen(true);
        break;
      case 'unbind':
        unBind(row);
        break;
      case 'syncLoc':
        onSyncLoc(row);
        break;
      case 'delete':
        onDelete(row);
        break;
      default:
        break;
    }
  };

  return (
    <PageHeaderWrapper>
      <List
        ref={listRef}
        onOperate={onOperate}
        toolBar={[
          <Button ghost key={1} type="primary" loading={syncing} onClick={onSyncShenSong}>
            同步深松
          </Button>,
          <Button ghost key={3} type="primary" loading={syncing2} onClick={onSyncFeiFang}>
            同步飞防
          </Button>,
          <Button ghost key={4} type="primary" loading={syncing3} onClick={onSyncMachine}>
            绑定农机
          </Button>,
        ]}
      />
      <Modal
        width={640}
        title={modalTitle}
        visible={open}
        maskClosable={false}
        footer={null}
        onCancel={onHide}
      >
        {actRef.current === 'add' ? (
          <FeiFangForm ref={ffRef} onCancel={() => setOpen(false)} onFinish={onAddDevice} />
        ) : (
          <MaBind onCancel={() => setOpen(false)} onFinish={onBind} />
        )}
      </Modal>
    </PageHeaderWrapper>
  );
};
