import request from '@/utils/request';

/**
 * 设备列表
 * @param {*} params
 * @returns
 */
export const getHatcDeviceList = (params) => request('/hatc-device', { params });

/**
 * 传感设备列表
 * @param {*} params
 * @returns
 */
export const getDeviceList = (params) => request('/device', { params });

/**
 * 通过设备号查询相关设备列表  选好了点击绑定时根据当前选择的设备id查询
 * 同终端列表
 * @param {*} params
 * @returns
 */
export const getTerminalDeviceList = (id) => request(`/hatc-device/${id}`);

/**
 * 设备相关信息
 * 查询农机Id详情
 * @param {*} params
 * @returns
 */
export const getDeviceDetail = (id) => request(`/machinery/${id}/device`);

//  新增修改设备信息
/**
 * 新增设备信息
 * @param {*} data
 * @returns
 */
export const addDevice = (data) => request('/device', { method: 'post', data });

/**
 * 保存农机
 * @param {*} data
 * @returns
 */
export const addMachinery = (data) => request('/device', { method: 'post', data });

/**
 * 取消绑定
 * @param {*} data
 * @returns
 */
export const deleteDevice = (params) => request(`/device`, { method: 'delete', params });

/**
 * 获取用户作业农机列表
 * @param {*} params
 * @returns
 */
export const getMachineryListByUser = (userId) => request(`/device-job/user/${userId}/machinery`);

/**
 * 同步深松设备
 * @returns
 */
export const syncShenSong = () => request('/raw-device/sync', { method: 'put' });

/**
 * 增加设备
 * @returns
 */
export const addRawDevice = (data, options) =>
  request('/raw-device', { method: 'POST', data, ...(options || {}) });

/**
 * 删除设备
 * @returns
 */
export const deleteRawDevice = (id) => request(`/raw-device/${id}`, { method: 'DELETE' });

/**
 * 同步位置信息
 * @returns
 */
export const syncLoc = (params) => request('/raw-device/sync-loc', { method: 'put', params });

/**
 * 同步农机
 * @returns
 */
export const syncMachine = () => request('/bind/sync-machine');
